package com.zhili.dashboard.scheduler;

import com.zhili.dashboard.service.IAlarmMsgService;
import com.zhili.dashboard.service.IAlarmMsgWarnService;
import com.zhili.dashboard.service.IDeviceDurationService;
import com.zhili.dashboard.service.IDeviceService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * @author user
 */
@Component
public class JobScheduler {
    @Resource
    IDeviceService deviceService;
    @Resource
    IAlarmMsgService alarmMsgService;
    @Resource
    IAlarmMsgWarnService alarmMsgWarnService;
    @Resource
    IDeviceDurationService deviceDurationService;
    /**
     * 同步电池信息
     * 10min一次
     */
    @Async
    @Scheduled(cron = "0 */10 * * * ?")
    public void syncBattery() {
        deviceService.syncBattery();
    }

    /**
     * 同步报警信息
     * 10min一次
     */
    @Async
    //@Scheduled(cron = "0 */2 * * * ?")
    public void syncAlarmMsg() {
        alarmMsgService.syncAlarmMsg();
    }

    /**
     * 同步预警信息
     * 2min一次
     */
    @Async
    //@Scheduled(cron = "0 */2 * * * ?")
    public void syncAlarmMsgWarnIng() {
        alarmMsgWarnService.syncAlarmMsg();
    }

    /**
     * 更新故障状态
     * 1小时一次
     */
    @Async
    @Scheduled(cron = "0 0 */1 * * ?")
    public void syncAlarmMsgStatus() {
        alarmMsgService.syncAlarmMsgStatus();
    }

    /**
     * 同步析锂时长信息
     * 1小时一次
     */
    @Async
    @Scheduled(cron = "0 0 */1 * * ?")
    public void syncDuration() {
        deviceDurationService.syncDuration();
    }
}
